Firewall <| |> -> Class['nova::compute::libvirt']

# Ensure Firewall changes happen before libvirt service start
# preventing a clash with rules being set by libvirt

if $::lsbdistid == "OracleVMserver" {
    $libvirt_type = "xen"
    $libvirt_cpu_mode = "none"
    nova_config{
      "DEFAULT/use_cow_images": value => "False";
      # Workaround for configuration bug
      "DEFAULT/libvirt_type": value => "$libvirt_type";
    }
}else{
    if $::is_virtual == "true" {
        $libvirt_type = "qemu"
        $libvirt_cpu_mode = "none"
    }else{
        $libvirt_type = "kvm"
        $libvirt_cpu_mode = "host-passthrough"
    }

    package { 'qemu-kvm':
        ensure => installed,
        before => Class['nova::compute::libvirt'],
    }

    exec {'load_kvm':
        user => 'root',
        command => '/bin/sh /etc/sysconfig/modules/kvm.modules',
        onlyif => '/usr/bin/test -e /etc/sysconfig/modules/kvm.modules',
    }

    file {'/dev/kvm':
        group => 'kvm',
        mode => '0666',
        require => Exec["load_kvm"],
    }

    Class['nova::compute']-> Exec["load_kvm"]
}

nova_config{
  "DEFAULT/libvirt_inject_partition": value => "-1";
}

class { 'nova::compute::libvirt':
  libvirt_virt_type           => "$libvirt_type",
  vncserver_listen            => "0.0.0.0",
  migration_support           => true,
  libvirt_cpu_mode            => "$libvirt_cpu_mode",
}

file_line { 'libvirt-guests':
    path  => '/etc/sysconfig/libvirt-guests',
    line  => 'ON_BOOT=ignore',
    match => '^[\s#]*ON_BOOT=.*',
    require => Class['nova::compute::libvirt']
}

# Remove libvirt's default network (usually virbr0) as it's unnecessary and can be confusing
exec {'virsh-net-destroy-default':
    onlyif  => '/usr/bin/virsh net-list | grep default',
    command => '/usr/bin/virsh net-destroy default',
    require => Package['libvirt'],
}

exec {'virsh-net-undefine-default':
    onlyif  => '/usr/bin/virsh net-list --inactive | grep default',
    command => '/usr/bin/virsh net-undefine default',
    require => Exec['virsh-net-destroy-default'],
}
